#!/bin/sh

test -f /usr/share/acpi-support/key-constants || exit 0

manufacturer=`dmidecode --string system-manufacturer`
case "$manufacturer" in
    LENOVO*)
	exit
    ;;
    *)
	. /usr/share/acpi-support/key-constants
	acpi_fakekey $KEY_BRIGHTNESSDOWN
    ;;
esac
